@@ -9,10 +9,10 @@ def Connection(config: Config):
     repository = Repository(config=config)
     try:
         yield repository
-        # repository.commit()
+        repository.commit()
     except Exception as e:
         Log.error(f'Error while running database operation: {e}')
         repository.rollback()
-        raise Exception()
+        raise Exception(e)
     finally:
         repository.close()
\ No newline at end of file
