@@ -199,6 +199,9 @@ class Scraper:
             return eval('element ' + condition)
         '''
 
+    def hover(self, path: str, element: any=None) -> None:
+        self.on_hover(path=path, element=element) 
+
     def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
         return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
 
@@ -206,7 +209,7 @@ class Scraper:
         return self.on_click(path=path, element=element, timeout=timeout)
 
     def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
-        self.click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout)
+        self.on_click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout)
 
     def back(self):
         self.on_back()
